import { FieldNode, FragmentDefinitionNode, GraphQLAbstractType, GraphQLField, GraphQLObjectType, GraphQLResolveInfo, GraphQLScalarType, GraphQLSchema, InlineFragmentNode } from "graphql";
export declare type GetFieldNameFunc = (field: GraphQLField<any, any>, type: GraphQLObjectType, schema: GraphQLSchema) => string | null;
export declare type GetAbstractTypeFieldMaskPathsFunc = (info: {
    node: InlineFragmentNode | FragmentDefinitionNode;
    abstractType: GraphQLAbstractType;
    concreteType: GraphQLObjectType;
    field: GraphQLField<any, any>;
}, getFieldMaskPaths: () => string[]) => string[];
export declare type GetCustomScalarTypeFieldMaskPathsFunc = (path: string, info: {
    node: FieldNode;
    type: GraphQLScalarType;
    field: GraphQLField<any, any>;
}) => string[];
export declare type FieldMaskPathsFromResolveInfoOptions = {
    /**
     * Get field name in field mask path.
     * If return `null`, this field is not included in field mask paths.
     */
    getFieldName?: GetFieldNameFunc;
    /**
     * Determine field mask paths in abstract type.
     * By default, it returns only the fields of the abstract type itself and ignores fragments of concrete types,
     * but you can change this behavior by defining `getAbstractTypeFieldMaskPaths`.
     */
    getAbstractTypeFieldMaskPaths?: GetAbstractTypeFieldMaskPathsFunc;
    /**
     * Determine field mask paths in custom scalar type.
     * By default, it returns only the field name of the scalar type.
     */
    getCustomScalarFieldMaskPaths?: GetCustomScalarTypeFieldMaskPathsFunc;
};
/**
 * Create field mask paths from `GraphQLResolveInfo`.
 *
 * @param typename Name of GraphQL object type
 * @param info
 * @param opts
 * @returns field mask paths
 */
export declare function fieldMaskPathsFromResolveInfo(typename: string, info: GraphQLResolveInfo, opts?: FieldMaskPathsFromResolveInfoOptions): string[];
//# sourceMappingURL=fieldMaskPathsFromResolveInfo.d.ts.map